<?php

/*Theme Supports*/
if ( ! isset( $content_width ) ){ $content_width = 900; }
add_action( 'after_setup_theme', 'umbrella_theme_setup' );
function umbrella_theme_setup(){
	add_theme_support( 'title-tag' );
    add_theme_support( 'woocommerce' );
    add_theme_support('post-thumbnails');
    add_theme_support('automatic-feed-links');
    load_theme_textdomain('um_lang', get_template_directory() . '/lang');
}
/*Theme Supports*/

/*Include ACF*/
add_filter('acf/settings/save_json', 'um_acf_json_path');
add_filter('acf/settings/load_json', 'um_acf_json_path');
function um_acf_json_path( $path ) {
    $paths = array(get_template_directory() . '/acf-json');
    if(is_child_theme()){
        $paths[] = get_stylesheet_directory() . '/acf-json';
    }
    return $paths;
}

include_once 'framework/acf/acf.php';
add_filter('acf/settings/path', 'um_acf_settings_path');
function um_acf_settings_path( $path ) {
    $path = get_template_directory() . '/framework/acf/';
    return $path;
}
add_filter('acf/settings/dir', 'um_acf_settings_dir');
function um_acf_settings_dir( $dir ) {
    $dir = get_template_directory_uri() . '/framework/acf/';
    return $dir;
}
add_filter('acf/settings/show_admin', '__return_false');
/*Include ACF*/

/*includes*/
//echo get_stylesheet_directory();
require_once get_stylesheet_directory().'/framework/Mustache/Autoloader.php';
    Mustache_Autoloader::register();
require_once "framework/mega_menu_walker.php";
require_once "framework/vc.php";
require_once "framework/woocommerce.php";
require_once "framework/aq_resizer.php";
require_once "framework/widgets/widgets.php";
require_once "framework/post-types.php";
require_once "framework/ui-code/acf-ui-code.php";
require_once "framework/ui-drag/acf-drag.php";
require_once "framework/ui-google-font/acf-ui-google-font.php";
require_once "framework/layout/shortcodes.php";
require_once "framework/shortcodes/shortcodes.php";
require_once "framework/tgm.php";
/*includes*/

/*
 * Mustache instance return and render view
 * */
function um_mustache_render($view,$params){
    if(class_exists('Mustache_Engine')){
        $m = new Mustache_Engine(array(
            'loader' => new Mustache_Loader_FilesystemLoader(get_stylesheet_directory()."/framework/layout/views"),
        ));
        return $m->render($view,$params);
    }
}

/*Register Option Pages*/
if( function_exists('acf_add_options_page') ) {

    acf_add_options_page(array(
        'page_title' 	=> 'Main',
        'menu_title'	=> 'Theme Settings',
        'menu_slug' 	=> 'main',
        'capability'	=> 'manage_options',
    ));

    acf_add_options_sub_page(array(
        'page_title' 	=> 'Main Settings',
        'menu_title'	=> 'Main Settings',
        'menu_slug' 	=> 'main_settings',
        'parent_slug'	=> 'main',
    ));

    acf_add_options_sub_page(array(
        'page_title' 	=> 'Branding',
        'menu_title'	=> 'Branding',
        'menu_slug' 	=> 'branding',
        'parent_slug'	=> 'main',
    ));

    acf_add_options_sub_page(array(
        'page_title' 	=> 'Typography',
        'menu_title'	=> 'Typography',
        'menu_slug' 	=> 'typography',
        'parent_slug'	=> 'main',
    ));

    acf_add_options_sub_page(array(
        'page_title' 	=> 'Popups',
        'menu_title'	=> 'Popups',
        'menu_slug' 	=> 'popups',
        'parent_slug'	=> 'main',
    ));

    acf_add_options_sub_page(array(
        'page_title' 	=> 'Footer & Sidebar',
        'menu_title'	=> 'Footer & Sidebar',
        'menu_slug' 	=> 'footer',
        'parent_slug'	=> 'main',
    ));

    acf_add_options_sub_page(array(
        'page_title' 	=> 'Registration & Signin',
        'menu_title'	=> 'Registration & Signin',
        'menu_slug' 	=> 'registration_signin',
        'parent_slug'	=> 'main',
    ));

}
/*Register Option Pages*/

/*Register Menu*/
add_action('init', 'um_register_menus');

function um_register_menus(){
    register_nav_menus(
        array(
            'main_menu' => __('Main Menu', "um_lang"),
            'mobile_menu' => __('Mobile Menu', "um_lang"),
        )
    );
}
/*Register Menu*/

/*Enqueue Admin Custom CSS and JS*/
add_action('admin_init', 'um_admin_init');
function um_admin_init(){
    wp_enqueue_script('json2');
    wp_enqueue_script('php_defaults', get_template_directory_uri() . "/assets/js/php.default.min.js", array(), 1.0, true);
    wp_enqueue_script('custom_admin', get_template_directory_uri() . "/assets/js/admin.js", array(), 1.0, true);
}
/*Enqueue Admin Custom CSS and JS*/

/*Enqueue JS and CSS*/
function um_enq_scripts_styles(){
    $d = get_template_directory_uri();

    wp_enqueue_style("um_font", "http://fonts.googleapis.com/css?family=Lato:400,700,400italic,700italic", false, "1.0");
    wp_enqueue_style("font-awesome", $d . "/assets/css/font-awesome.min.css", false, "1.0");
    wp_enqueue_style("bootstrap", $d . "/assets/css/bootstrap.min.css", false, "1.0");
	
	wp_enqueue_style("um_adjust", $d . "/assets/css/adjust.css", false, "1.0");
	wp_enqueue_style("default-style", $d . "/assets/css/style.css", false, "1.0");
	
	wp_enqueue_style("um_woocommerce", $d . "/assets/css/um-woocommerce.css", array('woocommerce-layout','woocommerce-smallscreen','woocommerce-general'), "1.0");
	if(um_is_woocommerce_active()){
		wp_enqueue_style("dynamic-css", $d . "/assets/css/dynamic.php", array('woocommerce-layout','woocommerce-smallscreen','woocommerce-general'), "1.0");
	}else{
		wp_enqueue_style("dynamic-css", $d . "/assets/css/dynamic.php", false, "1.0");
	}
	
    wp_enqueue_style("animate", $d . "/assets/css/animate.css", false, "1.0");
    wp_enqueue_style("default_style",get_stylesheet_uri(),false);

    wp_enqueue_script("jquery");
    wp_enqueue_script( 'comment-reply' );
    wp_enqueue_script( 'googl_maps',"https://maps.googleapis.com/maps/api/js?v=3.exp&sensor=false&ver=1",null,"1.0",true);

    wp_enqueue_script( 'googl_maps',"https://maps.googleapis.com/maps/api/js?v=3.exp&sensor=false&ver=1",array(),1.0,true);
    wp_enqueue_script( 'imgLiquid',$d."/assets/js/imgLiquid-min.js",null,"1.0",true);
    wp_enqueue_script( 'modernizr',$d."/assets/js/moderniz.js",null,"1.0",true);
    if(get_field("smoothscroll","options") != "Disabled") {
        wp_enqueue_script('smoothscroll', $d . "/assets/js/jquery.smoothscroll.js", null, "1.0", true);
    }
    wp_enqueue_script( 'selectric',$d."/assets/js/jquery.selectric.min.js",null,"1.0",true);
    wp_enqueue_script( 'handlebars',$d."/assets/js/handlebars-v3.0.0.js",null,"1.0",true);
    wp_enqueue_script( 'typehead',$d."/assets/js/typeahead.bundle.js",null,"1.0",true);
    wp_enqueue_script( 'script',$d."/assets/js/script.js",null,"1.0",true);
}
add_action( 'wp_enqueue_scripts', 'um_enq_scripts_styles' );
/*Enqueue JS and CSS*/

/*Get Post Featured Image SRC*/
function um_get_post_featured_image_src($post_id = null,$size = "full"){
    if(!$post_id){
        global $post;
        $post_id = $post->ID;
    }
    if(has_post_thumbnail($post_id)){
        $image = wp_get_attachment_image_src( get_post_thumbnail_id( $post_id ), $size );
        return $image[0];
    }else{
        return "";
    }
}
/*Get Post Featured Image SRC*/

/*Sidebar*/
function sidebar_widgets_init(){

    register_sidebar( array(
        'name' => __('Shop' , "um_lang"),
        'id' => 'shop',
        'description' => __( 'Shop' ,"um_lang" ),
        'before_widget' => '<div id="%1$s" class="um-widget widget col-sm-12 %2$s">',
        'after_widget' => "</div>",
        'before_title' => '<h5 class="widget-title">',
        'after_title' => '</h5>',
    ) );

    register_sidebar( array(
        'name' => __('Sidebar' , "um_lang"),
        'id' => 'sidebar',
        'description' => __( 'Sidebar' ,"um_lang" ),
        'before_widget' => '<div id="%1$s" class="um-widget widget col-sm-12 %2$s">',
        'after_widget' => "</div>",
        'before_title' => '<h5 class="widget-title">',
        'after_title' => '</h5>',
    ) );

    register_sidebar( array(
        'name' => __('Footer' , "um_lang"),
        'id' => 'footer',
        'description' => __( 'Sidebar' ,"um_lang" ),
        'before_widget' => '<div id="%1$s" class="um-widget widget col-sm-3 %2$s">',
        'after_widget' => "</div>",
        'before_title' => '<div class="widget_title"><h5>',
        'after_title' => '</h5></div>',
    ) );

    /*
     * Dynamic Sidebars
     * */
    $sidebars = get_field("sidebars","options");
    if($sidebars){
        foreach ($sidebars as $s) {
            $sid = sanitize_title_with_dashes($s["sidebar"]);
            register_sidebar( array(
                'name' => $s["sidebar"],
                'id' => $sid,
                'description' => __( 'Dynamic : ' ,"um_lang" ).$s["sidebar"],
                'before_widget' => '<div id="%1$s" class="um-widget widget col-sm-12 %2$s">',
                'after_widget' => "</div>",
                'before_title' => '<h5 class="widget-title">',
                'after_title' => '</h5>',
            ) );
        }

    }
}

add_action( 'widgets_init', 'sidebar_widgets_init' );
/*Sidebar*/

/*Is woocommerce active*/
function um_is_woocommerce_active(){
    return WC() instanceof WooCommerce;
}
/*Is woocommerce active*/

/*Sidebar Select Custom Fields Dynamic Population*/
function um_load_sidebars_dynamic_select($field){

    $field['choices'] = array();
    global $wp_registered_sidebars;
    if($wp_registered_sidebars && is_array($wp_registered_sidebars)){
        foreach ($wp_registered_sidebars as $sdb) {
            $field['choices'][$sdb['id']] = $sdb['name'];
        }
    }
    return $field;

}
add_filter('acf/load_field/key=field_54ecbd83881b4', 'um_load_sidebars_dynamic_select');
/*Sidebar Select Custom Fields Dynamic Population*/

/*
 * Search JSON
 * */
add_action( 'wp_ajax_um_search_product', 'um_search_product' );
add_action( 'wp_ajax_nopriv_um_search_product', 'um_search_product' );

function um_search_product(){
    $posts = array();
    $args = array();
    $args['post_type'] = 'product';
    $args['posts_per_page'] = -1;
    $args['post_status'] = 'publish';
    $args['s'] = $_REQUEST['keyword'];
    $the_query = new WP_Query( $args );
    while($the_query->have_posts()){
        $the_query->the_post();
        global $post;
        $tmp_post = array();
        $tmp_post['url'] = get_permalink($post->id);
        $tmp_post['value'] = get_the_title($post->id);
        array_push($posts,$tmp_post);
    }
    wp_reset_postdata();
    wp_send_json($posts);
    die;
}

/*
 * Custom rewrite rules for sign in and register
 * */
if(get_field("custom_registration","options") != "Disabled"){
    add_action( 'init', 'um_add_rewrite_rules' );
    function um_add_rewrite_rules(){

        $signin = get_field("signin_slug","options") ? get_field("signin_slug","options") : "signin";
        $register = get_field("register_slug","options") ? get_field("register_slug","options") : "register";

        add_rewrite_rule('^'.$signin.'/?','index.php?umsignin=1','top');
        add_rewrite_rule('^'.$register.'/?','index.php?umregister=1','top');
        add_rewrite_rule('^reset-password/?','index.php?umresetpassword=1','top');
        add_rewrite_rule('^wish-list/?','index.php?umwishlist=1','top');
    }

    add_filter( 'query_vars', 'um_add_query_vars' );
    function um_add_query_vars( $query_vars )
    {
        $query_vars[] = 'umsignin';
        $query_vars[] = 'umregister';
        $query_vars[] = 'umresetpassword';
        $query_vars[] = 'umwishlist';
        return $query_vars;
    }

    add_filter( 'template_redirect', 'um_get_temlpate_with_custom_permalink' );
    function um_get_temlpate_with_custom_permalink(){
        global $wp_query;
        if( $wp_query->get( 'umsignin' ) ):
            get_template_part("signin");
            exit();
        endif;
        if( $wp_query->get( 'umregister' ) ):
            get_template_part("register");
            exit();
        endif;
        if( $wp_query->get( 'umresetpassword' ) ):
            get_template_part("reset","password");
            exit();
        endif;
        if( $wp_query->get( 'umwishlist' ) ):
            get_template_part("wish","list");
            exit();
        endif;
    }
}

/*
 * Get cart total
 * */
function um_get_cart_total_items(){
    if(um_is_woocommerce_active()){
        global $woocommerce;
        return $woocommerce->cart->cart_contents_count;
    }else{
        return 0;
    }
}

function um_cart_total_items(){
    echo um_get_cart_total_items();
    die;
}
add_action( 'wp_ajax_um_get_cart_totals', 'um_cart_total_items' );
add_action( 'wp_ajax_nopriv_um_get_cart_totals', 'um_cart_total_items' );


/*
 * Wish list
 * */
$UM_WISHTLIST = array();
global $UM_WISHTLIST;

add_action( 'wp_ajax_um_add_product_to_wish_list', 'um_add_product_to_wish_list_logged_in' );
function um_add_product_to_wish_list_logged_in(){
    $product = $_REQUEST["product_id"];
    $cur_user = wp_get_current_user();
    global $UM_WISHTLIST;
    if($product && !in_array($product,get_user_meta($cur_user->ID,"um_wishtlist"))){
        add_user_meta($cur_user->ID,"um_wishtlist",$product);
        echo 1;
    }else if($product && um_is_product_wish_listed($product)){
        if(($key = array_search($product,$UM_WISHTLIST)) !== false){
            unset($UM_WISHTLIST[$key]);
            global $wpdb;
            $sql = $wpdb->prepare("DELETE from {$wpdb->usermeta} WHERE user_id = %d and meta_key = %s", 1,'um_wishtlist');
            $wpdb->query( $sql );
            add_user_meta($cur_user->ID,"um_wishtlist",$UM_WISHTLIST);
        }
        echo 1;
    }
    um_fill_wisht_list();
    die;
}

add_action('wp_ajax_nopriv_um_add_product_to_wish_list', 'um_add_product_to_wish_list_not_logged_in');
function um_add_product_to_wish_list_not_logged_in(){
    $product = $_REQUEST["product_id"];
    if($product && um_is_product_wish_listed($product)){
        setcookie("um_wishtlist[".$product."]",null,time()-1,COOKIEPATH);
        unset($_COOKIE["um_wishtlist"][$product]);
        echo 1;
    }
    else{
        if($product){
            setcookie("um_wishtlist[".$product."]", intval($product) ,strtotime( '+30 days' ),COOKIEPATH);
            echo 1;
        }
    }
    um_fill_wisht_list();
    die;
}

function um_fill_wisht_list(){
    global $UM_WISHTLIST;
    $cur_user = wp_get_current_user();
    if($cur_user->ID){
        $UM_WISHTLIST = get_user_meta($cur_user->ID,"um_wishtlist");
    }else{
        if(isset($_COOKIE["um_wishtlist"])){
            $UM_WISHTLIST = $_COOKIE["um_wishtlist"];
        }
    }
}
add_action("init","um_fill_wisht_list",1);

function um_is_product_wish_listed($product_id){
    global $UM_WISHTLIST;
    return in_array((String)$product_id,$UM_WISHTLIST);
}

function um_get_wish_list_products(){
    global $UM_WISHLIST;
    um_fill_wisht_list();
    return $UM_WISHLIST;
}

/*
 * Generate video embed
 * */
function um_getVideoEmbed($vurl,$height = "100%",$width="100%"){
    $image_url = parse_url($vurl);
    // Test if the link is for youtube
    $youtube_autoplay = get_field("video_autoplay","options") == "Enabled" ? "&autoplay=1" : "";
    if($image_url['host'] == 'www.youtube.com' || $image_url['host'] == 'youtube.com'){
        $array = explode("&", $image_url['query']);
        return '<iframe class="youtube" src="http://www.youtube.com/embed/' . substr($array[0], 2) . '?wmode=transparent&enablejsapi=1'.$youtube_autoplay.'" width="'.$width.'" height="'.$height.'" frameborder="0" allowfullscreen></iframe>'; // Returns the youtube iframe embed code
        // Test if the link is for the shortened youtube share link
    } else if($image_url['host'] == 'www.youtu.be' || $image_url['host'] == 'youtu.be'){
        $array = ltrim($image_url['path'],'/');
        return '<iframe class="youtube" src="http://www.youtube.com/embed/' . $array . '?wmode=transparent&enablejsapi=1'.$youtube_autoplay.'" width="'.$width.'" height="'.$height.'" frameborder="0" allowfullscreen></iframe>'; // Returns the youtube iframe embed code
        // Test if the link is for vimeo
    } else if($image_url['host'] == 'www.vimeo.com' || $image_url['host'] == 'vimeo.com'){
        $hash = substr($image_url['path'], 1);
        return '<iframe class="vimeo" src="http://player.vimeo.com/video/' . $hash . '?title=0&byline=0&portrait=0&api=1'.$youtube_autoplay.'" width="'.$width.'" height="'.$height.'" frameborder="0" webkitAllowFullScreen allowfullscreen></iframe>'; // Returns the vimeo iframe embed code
    }
}

/*
 * Theme plugins - TGM Configuration
 * */
add_action( 'tgmpa_register', 'um_register_required_plugins' );

function um_register_required_plugins(){
    $plugins = array(
        array(
            'name'      => 'WooCommerce',
            'slug'      => 'woocommerce',
            'required'  => true,
        ),
        array(
            'name'      => 'WooCommerce Shortcodes',
            'slug'      => 'woocommerce-shortcodes',
            'required'  => true,
        ),
        array(
            'name'      => 'Simple Subscribe',
            'slug'      => 'simple-subscribe',
            'required'  => true,
        ),
        array(
            'name'      => 'Contact Form 7',
            'slug'      => 'contact-form-7',
            'required'  => true,
        ),
    );

    $config = array(
        'default_path' => '',                      // Default absolute path to pre-packaged plugins.
        'menu'         => 'tgmpa-install-plugins', // Menu slug.
        'has_notices'  => true,                    // Show admin notices or not.
        'dismissable'  => true,                    // If false, a user cannot dismiss the nag message.
        'dismiss_msg'  => '',                      // If 'dismissable' is false, this message will be output at top of nag.
        'is_automatic' => false,                   // Automatically activate plugins after installation or not.
        'message'      => '',                      // Message to output right before the plugins table.
        'strings'      => array(
            'page_title'                      => __( 'Install Required Plugins', 'tgmpa' ),
            'menu_title'                      => __( 'Install Plugins', 'tgmpa' ),
            'installing'                      => __( 'Installing Plugin: %s', 'tgmpa' ), // %s = plugin name.
            'oops'                            => __( 'Something went wrong with the plugin API.', 'tgmpa' ),
            'notice_can_install_required'     => _n_noop( 'This theme requires the following plugin: %1$s.', 'This theme requires the following plugins: %1$s.' ), // %1$s = plugin name(s).
            'notice_can_install_recommended'  => _n_noop( 'This theme recommends the following plugin: %1$s.', 'This theme recommends the following plugins: %1$s.' ), // %1$s = plugin name(s).
            'notice_cannot_install'           => _n_noop( 'Sorry, but you do not have the correct permissions to install the %s plugin. Contact the administrator of this site for help on getting the plugin installed.', 'Sorry, but you do not have the correct permissions to install the %s plugins. Contact the administrator of this site for help on getting the plugins installed.' ), // %1$s = plugin name(s).
            'notice_can_activate_required'    => _n_noop( 'The following required plugin is currently inactive: %1$s.', 'The following required plugins are currently inactive: %1$s.' ), // %1$s = plugin name(s).
            'notice_can_activate_recommended' => _n_noop( 'The following recommended plugin is currently inactive: %1$s.', 'The following recommended plugins are currently inactive: %1$s.' ), // %1$s = plugin name(s).
            'notice_cannot_activate'          => _n_noop( 'Sorry, but you do not have the correct permissions to activate the %s plugin. Contact the administrator of this site for help on getting the plugin activated.', 'Sorry, but you do not have the correct permissions to activate the %s plugins. Contact the administrator of this site for help on getting the plugins activated.' ), // %1$s = plugin name(s).
            'notice_ask_to_update'            => _n_noop( 'The following plugin needs to be updated to its latest version to ensure maximum compatibility with this theme: %1$s.', 'The following plugins need to be updated to their latest version to ensure maximum compatibility with this theme: %1$s.' ), // %1$s = plugin name(s).
            'notice_cannot_update'            => _n_noop( 'Sorry, but you do not have the correct permissions to update the %s plugin. Contact the administrator of this site for help on getting the plugin updated.', 'Sorry, but you do not have the correct permissions to update the %s plugins. Contact the administrator of this site for help on getting the plugins updated.' ), // %1$s = plugin name(s).
            'install_link'                    => _n_noop( 'Begin installing plugin', 'Begin installing plugins' ),
            'activate_link'                   => _n_noop( 'Begin activating plugin', 'Begin activating plugins' ),
            'return'                          => __( 'Return to Required Plugins Installer', 'tgmpa' ),
            'plugin_activated'                => __( 'Plugin activated successfully.', 'tgmpa' ),
            'complete'                        => __( 'All plugins installed and activated successfully. %s', 'tgmpa' ), // %s = dashboard link.
            'nag_type'                        => 'updated' // Determines admin notice type - can only be 'updated', 'update-nag' or 'error'.
        )
    );
    tgmpa( $plugins, $config );
}

/*
 * Documentation Menu Page
 * */
add_action('admin_menu', 'um_register_my_custom_submenu_page' , 99);

function um_register_my_custom_submenu_page() {
    add_submenu_page( 'main_settings', 'Documentation', 'Documentation', 'manage_options', 'admin.php?page=um_documentation', 'um_documentation_menu_callback' );
}

function um_documentation_menu_callback(){
    ?>
    <div class="icon32" id="icon-options-general"><br></div>
    <h2><?php _e("Documentation","um_lang"); ?></h2>
    <iframe width="100%" height="800px" src="http://documentation.umbrella.al/t-documentation/" frameborder="0"></iframe>
<?php
}

/*
 * Flush rules on theme activation
 * */
function um_reflush_rules() {
    global $wp_rewrite;
    $wp_rewrite->flush_rules();
}
add_action( 'after_switch_theme', 'um_reflush_rules' );

/*
 * Allow font file types to upload on media library
 * */
add_filter('upload_mimes', 'um_allow_upload_font_files');
function um_allow_upload_font_files( $existing_mimes = array() ) {
    // add your extension to the array
    $existing_mimes['eot'] = 'application/vnd.ms-fontobject';
    $existing_mimes['svg'] = 'image/svg+xml';
    $existing_mimes['woff'] = 'application/font-woff';
    $existing_mimes['ttf'] = 'application/font-ttf';
    return $existing_mimes;
}

/*
 * Add dialog on admin
 * */
add_action('admin_footer', 'um_add_dialog_markup_on_admin');
function um_add_dialog_markup_on_admin() {
    ?>
    <div id="um_dialog" style="display: none;">
        <label for="um_product"><?php _e("Place a product ID","um_lang");?></label>
        <input type="text" name="um_product" id="um_product"/>
        <br/>
        <label for="um_flip_point"><?php _e("Flip Point","um_lang");?></label>
        <input type="checkbox" name="um_flip_point" id="um_flip_point"/>
        <br/>
        <a class="um_save_point" href="#"><?php _e("Save","um_lang");?></a>
        <a class="um_delete_point" href="#"><?php _e("Delete","um_lang");?></a>
    </div>
<?php
}